import 'package:flutter/widgets.dart';
import 'package:rec_api_dart/src/entities/entity.base.dart';

class Badge extends Entity {
  final String name;
  final String nameEs;
  final String nameCa;

  final String description;
  final String descriptionEs;
  final String descriptionCa;

  final String group;
  final String groupEs;
  final String groupCa;

  final String? imageUrl;

  final bool enabled;

  Badge({
    String? id,
    String? createdAt,
    String? updatedAt,
    required this.name,
    required this.nameEs,
    required this.nameCa,
    required this.group,
    required this.groupEs,
    required this.groupCa,
    required this.description,
    required this.descriptionEs,
    required this.descriptionCa,
    required this.enabled,
    required this.imageUrl,
  }) : super(id, createdAt, updatedAt);

  /// Returns the [name] for the current locale, if locale is not handled it will return [name]
  String getNameForLocale(Locale locale) {
    switch (locale.languageCode) {
      case 'es':
        return nameEs;
      case 'ca':
        return nameCa;
      case 'en':
      default:
        return name;
    }
  }

  /// Returns the [description] for the current locale, if locale is not handled it will return [name]
  String getDescriptionForLocale(Locale locale) {
    switch (locale.languageCode) {
      case 'es':
        return descriptionEs;
      case 'ca':
        return descriptionCa;
      case 'en':
      default:
        return description;
    }
  }

  factory Badge.fromJson(Map<String, dynamic> data) {
    return Badge(
      id: '${data['id']}',
      createdAt: data['created'],
      updatedAt: data['updated'],
      enabled: data['enabled'] ?? false,
      imageUrl: data['image_url'],
      name: data['name'],
      nameEs: data['name_es'],
      nameCa: data['name_ca'],
      group: data['group'] ?? 'general',
      groupEs: data['group_es'] ?? 'general',
      groupCa: data['group_ca'] ?? 'general',
      description: data['description'],
      descriptionEs: data['description_es'],
      descriptionCa: data['description_ca'],
    );
  }
}
