import 'package:http/http.dart';
import 'package:rec_api_dart/rec_api_dart.dart';

/// This service is in charge of all requests related to [Award]s
///
/// * **Authentication Required** - the user must be authenticated
class AwardsService extends ServiceBase {
  AwardsService({required EnvBase env, Client? client})
      : super(
          env: env,
          client: client,
          interceptors: [UserTokenInterceptor()],
        );

  Future<ApiListResponse<Award>> getAwards() {
    final path = ApiPaths.allAwards.asUri(env.API_URL);
    return this.get(path).then(_mapAwards);
  }

  Future<ApiListResponse<AccountAward>> getAccountAwards(String accountId) {
    final path = ApiPaths.account.append(accountId).append(ApiPaths.awards.path);
    return this.get(path.asUri(env.API_URL)).then(_mapAccountAwards);
  }

  Future<ApiListResponse<AccountAwardItem>> getAccountAwardItems(
    String accountId, {
    int offset = 0,
    int limit = 5,
    String? awardId,
  }) {
    final path = ApiPaths.account.appendMultiple(
      [accountId, ApiPaths.awardItems.path],
    ).withQueryParams({
      'offset': '$offset',
      'limit': '$limit',
      if (awardId != null) 'award_id': awardId,
    });

    return this.get(path.asUri(env.API_URL)).then(_mapAccountAwardItems);
  }

  ApiListResponse<Award> _mapAwards(Map<String, dynamic> data) {
    return ApiListResponse<Award>.fromJson(
      data['data'],
      mapper: (el) => Award.fromJson(el),
    );
  }

  ApiListResponse<AccountAward> _mapAccountAwards(Map<String, dynamic> data) {
    return ApiListResponse<AccountAward>.fromJson(
      data['data'],
      mapper: (el) => AccountAward.fromJson(el),
    );
  }

  ApiListResponse<AccountAwardItem> _mapAccountAwardItems(Map<String, dynamic> data) {
    return ApiListResponse<AccountAwardItem>.fromJson(
      data['data'],
      mapper: (el) => AccountAwardItem.fromJson(el),
    );
  }
}
